import type React from "react";
import { useState } from "react";
import { SecondaryHeader, Header } from "@fchh/fcos-suite-ui";
import { Email, Search, UserAvatar, Notification } from "@carbon/icons-react";
import type { IMenuItem } from "@interfaces/IMenu";
import { LANGUAGES } from "@config";
import { setLanguage as changeLanguageLocalStorage } from "@utils";
import Icon from "@components/Icon";

const EXTENDED_TOOLBAR_ITEMS = [
  {
    title: "Search",
    icon: <Search size={24} />,
    target: "/search",
  },
  {
    title: "Email",
    icon: <Email size={24} />,
    target: "/email",
  },
  {
    title: "Notification",
    icon: <Notification size={24} />,
    target: "/notification",
  },
  {
    title: "User",
    icon: <UserAvatar size={24} />,
    target: "/user",
  },
];

const LOCALES = LANGUAGES.map((l) => l.locale.toLowerCase());

interface Props {
  menuItems: Array<IMenuItem>;
  compact?: boolean;
  path?: string;
  baseUrl: string;
  localeFromUrl?: string;
  logoLinkTarget?: string;
  disableAnimation?: boolean;
  compactBackground?: string;
  light?: boolean;
  className?: string;
  backgroundImageClasses?: string;
  itemsAlwaysLight?: boolean;
  toolbarData?: CollectionSchema<"toolbar">[]
}

export const HeaderWrapper: React.FC<Props> = ({
  menuItems,
  compact,
  path,
  baseUrl,
  localeFromUrl,
  logoLinkTarget,
  disableAnimation,
  light,
  className,
  backgroundImageClasses,
  itemsAlwaysLight,
  toolbarData,
}: Props) => {
  const toolbar = toolbarData
    .map((item) => {
      return {
        ...item,
        icon: (
          <Icon
            name={item.icon}
            className="w-6 sm:w-5 h-6 sm:h-5 sm:mr-2 mb-1 sm:mb-0"
          />
        ),
        target: baseUrl + item.target
      };
    })
    .sort((a, b) => a.order - b.order);

  const [selectedLanguage, setSelectedLanguage] = useState(
    localeFromUrl || LOCALES[0]
  );

  // Changing the language requires only to change the locale in the URL
  // The rest (slug) will be handled by redirect logic
  const changeLanguage = (newLanguage: string) => {
    changeLanguageLocalStorage(newLanguage);
    setSelectedLanguage(newLanguage);
    const pathWithoutBaseUrl = path
      ?.replace(baseUrl, "")
      ?.split("/")
      .filter(Boolean)
      .slice(1)
      .join("/");
    const newLocation = `${baseUrl}${newLanguage}/${pathWithoutBaseUrl}`;

    window.location.pathname = newLocation;
  };

  const commonProps = {
    className,
    topBarItems: menuItems,
    toolBarItems: toolbar,
    extendedToolBarItems: EXTENDED_TOOLBAR_ITEMS,
    languages: LOCALES,
    onChangeLanguage: (newLanguage: string) => changeLanguage(newLanguage),
    selectedLanguage,
    logoLinkTarget,
    disableAnimation,
    light,
  };

  return compact ? (
    <SecondaryHeader
      {...commonProps}
      backgroundImageClasses={backgroundImageClasses}
      hideSearchIcon
      itemsAlwaysLight={itemsAlwaysLight}
    />
  ) : (
    <Header {...commonProps} />
  );
};
